@@ -1,5 +1,4 @@
-#!/usr/bin/env python3
-# Begin lsbinitd.py
+# Begin lsbtools/__init__.py
 
 import glob, itertools, os, re, sys
 from io import StringIO
@@ -138,7 +137,7 @@ def get_matrix(initdDir, debug):
   return matrix
 
 def get_prog_ver(strprogram):
-  progver = strprogram + " " + " (LSB-Tools-0.6)"
+  progver = strprogram + " " + " (LSB-Tools-0.7)"
   return progver
 
 def install_font(argobject):
@@ -168,7 +167,6 @@ def install_font(argobject):
       os.chmod(fontfile, 0o644)
       sys.exit(0)
 
-
 def install_init(argobject):
   initdDir = lsbtools.find_initd_dir()
   aobject = os.path.basename(argsobject).strip(" ")
@@ -196,7 +194,6 @@ def install_init(argobject):
       os.chmod(initfile, 0o644)
       sys.exit(0)
 
-
 def install_profile(argobject):
   profileDir = "/etc/profile.d"
   aobject = os.path.basename(argsobject).strip(" ")
@@ -224,7 +221,6 @@ def install_profile(argobject):
       os.chmod(profilefile, 0o644)
       sys.exit(0)
 
-
 def install_service(argobject):
   portproto = argobject[0].split("/")
   if len(portproto) != 2:
@@ -276,4 +272,27 @@ def install_service(argobject):
     print("Service", portservice, "with port", portproto[0], "on protocol", portproto[1], "exists.")
     sys.exit(0)
 
+def install_inet(argsobject):
+  print("Not implemented...")
+  sys.exit(0)
+
+def install_crontab(argsobject):
+  print("Not implemented...")
+  sys.exit(0)
+
+def install_package(argsobject):
+  print("Not implemented...")
+  sys.exit(0)
+
+def install_menu(argsobject):
+  print("Not implemente...")
+  sys.exit(0)
+
+def install_ldconfig(argsobject):
+  print("Not implemente...")
+  sys.exit(0)
+
+def install_man(argsobject):
+  print("Not implemente...")
+  sys.exit(0)
 
